%define build_flavor ETL%nil
%define pkg synfig
%define soname_core libsynfig
%define sover_core 0
%define soname_studio libsynfigapp
%define sover_studio 0
%global __provides_exclude_from ^%_libdir/%pkg/[^/]+/.*\\.so(|\\.[0-9].*)$
Name:           synfig
Version:        1.5.3
Release:        1699.1.pm.3
Summary:        Vector based 2D animation render
License:        GPL-3.0+
URL:            https://synfig.org
Source0:        %pkg-%version.tar
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
Requires:       libmlt7-modules
Conflicts:      synfig-modules < %version-%release
Conflicts:      synfig-modules-debuginfo < %version-%release
#
%description
Synfig Studio is a free and open-source 2D animation software,
designed as powerful industrial-strength solution for creating
film-quality animation using a vector and bitmap artwork. It
eliminates the need to create animation frame-by frame, allowing
you to produce 2D animation of a higher quality with fewer people
and resources.

This package contains the command line renderer used to convert synfig .sif 
files to raster images, videos and other formats. Layer types include 
geometric, gradient, filter, distortion, transformation, fractal and 
others.

%if "%build_flavor" == ""
%package -n     %soname_core%sover_core
BuildRequires:  intltool
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  pkgconfig(ETL) = %version
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(giomm-2.4)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libdv)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  pkgconfig(mlt++-7)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(zlib)
Summary:        Shared library part of %pkg

%description -n %soname_core%sover_core
Vector based 2D animation render.

This package contains the shared library.

%package        devel
Summary:        Header files for the %pkg library
Requires:       %soname_core%sover_core = %version-%release
Provides:       %soname_core-devel = %version-%release
Obsoletes:      %soname_core-devel < %version-%release

%description    devel
Vector based 2D animation render.

This package contains the pkgconfig, header files and libraries needed to
develop application that use %pkg.

%lang_package
%endif
#
%if "%build_flavor" == "ETL"
%package -n     ETL-devel
BuildRequires:  pkgconfig(glibmm-2.4)
Summary:        Extended Class and Template Library

%description -n ETL-devel
ETL is a multi-platform class and template library designed to add
new datatypes and functions which combine well with the existing
types and functions from the C++ Standard Template Library (STL).
%endif
#
#
%if "%build_flavor" == "studio"
%package -n     synfigstudio
BuildRequires:  intltool
BuildRequires:  %soname_core%sover_core = %version
BuildRequires:  %pkg
BuildRequires:  pkgconfig(ETL)
BuildRequires:  pkgconfig(synfig) = %version
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(fontconfig)
Summary:        GUI of %pkg
Requires:       %pkg = %version
Requires:       %soname_studio%sover_studio = %version-%release

%description -n synfigstudio

%package -n     synfigstudio-devel
Summary:        Header files for the %soname_studio%sover_studio library
Requires:       %soname_studio%sover_studio = %version-%release
%description -n synfigstudio-devel

%package -n     %soname_studio%sover_studio
Summary:        Shared library part of %pkg
%description -n %soname_studio%sover_studio
%lang_package
%endif

%prep
%autosetup -p1 -n %pkg-%version

%build
%if "%build_flavor" == ""
pushd synfig-core
>> AUTHORS
>> NEWS
>> README
bash -x bootstrap.sh
%endif
%if "%build_flavor" == "ETL"
pushd ETL
>> AUTHORS
>> NEWS
>> README
autoreconf -fiv
%endif
%if "%build_flavor" == "studio"
pushd synfig-studio
>> AUTHORS
>> NEWS
>> README
bash -x bootstrap.sh
%endif
CFLAGS='%optflags -Wno-deprecated-declarations'
CXXFLAGS='%optflags -Wno-deprecated-declarations -Wno-unused-parameter'
%configure --help
%configure \
	--enable-nls \
	--disable-update-mimedb \
	%nil
%make_build -k

%install
%if "%build_flavor" == ""
pushd synfig-core
%endif
%if "%build_flavor" == "ETL"
pushd ETL
%endif
%if "%build_flavor" == "studio"
pushd synfig-studio
%endif
%make_install
popd
find %buildroot -type f -name '*.la' -print -delete
%if "%build_flavor" == ""
%find_lang %pkg %{?no_lang_C} --without-gnome --without-kde
%endif
%if "%build_flavor" == "studio"
%find_lang synfigstudio %{?no_lang_C} --without-gnome --without-kde
%endif

%if "%build_flavor" == ""
%post -n %soname_core%sover_core -p /sbin/ldconfig
%postun -n %soname_core%sover_core -p /sbin/ldconfig

%files
%license LICENSE
%_bindir/%pkg
%_libdir/%pkg
%config %_sysconfdir/*

%files -n %soname_core%sover_core
%_libdir/%soname_core.so.*

%files devel
%_bindir/%pkg-config
%_includedir/*
%_libdir/%soname_core.so
%_libdir/pkgconfig/*.pc

%files lang -f %pkg.lang
%endif
#
%if "%build_flavor" == "ETL"
%files -n ETL-devel
%_bindir/*
%_includedir/*
%_libdir/pkgconfig/*.pc
%endif
#
%if "%build_flavor" == "studio"
%post -n %soname_studio%sover_studio -p /sbin/ldconfig
%postun -n %soname_studio%sover_studio -p /sbin/ldconfig

%files -n %soname_studio%sover_studio
%_libdir/%soname_studio.so.*

%files lang -f synfigstudio.lang

%files -n synfigstudio
%_bindir/*
%_datadir/%pkg
%_datadir/appdata/*
%_datadir/applications/*
%_datadir/icons/*
%_datadir/mime-info
%_datadir/mime/packages/*

%files -n synfigstudio-devel
%_includedir/*
%_libdir/%soname_studio.so
%endif

%changelog
* Wed Jan 11 2017 avvissu@yandex.by
- Update to 1.2.0:
  * see: /usr/share/doc/packages/synfig/NEWS
- Drop patches (fixed in upstream):
  * synfig-1.0.2_c++11.patch
  * synfig-isnan.patch
  * synfig-math_h.patch
* Sat Apr  2 2016 avvissu@yandex.by
- Update to 1.0.2:
  * see: /usr/share/doc/packages/synfig/NEWS
- Remove patches:
  * synfig-devel-deps.patch	(fixed in upstream)
  * synfig-intltoolize.patch (use autoreconf only)
  * synfig-lyr_freetype.patch (fixed in upstream)
  * synfig-no-buildtime.patch (use sed in spec-file)
- Update patches:
  * synfig-configure-debug.patch -> synfig-1.0.2_debug.patch
- Add patches:
  * synfig-1.0.2_c++11.patch
- Build witch support libdv
- Create the new package: modules, doc
- Cleanup the descriptions for packages
- Spec-file cleanup
* Mon Jun 22 2015 olaf@aepfle.de
- update to 1.0
* Tue Nov  5 2013 obs@botter.cc
- update to 0.64.1
* Sun Apr 15 2012 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.05-0
- update to 0.63.05
* Mon Oct 24 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.02-0.pm.1
- update to 0.63.02
* Sat Jun 11 2011 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.63.00-0.pm.1
- update to 0.63.00 (git logout, because there's no source tarball)
* Mon Nov 15 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.02-1.pm.1
- update to 0.62.02
* Wed Jul 14 2010 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.01-1.pm.1
- update to 0.62.01
* Wed Nov  4 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.62.00-0.pm.1
- update to 0.62.00
* Wed Sep 23 2009 Manfred Tremmel <Manfred.Tremmel@iiv.de> - 0.61.09-1.pm.4
- added patch to compile it with gcc 4.4 (openSUSE 11.2)
* Sat Sep  5 2009 Manfred.Tremmel <Manfred.Tremmel@iiv.de> - 0.61.09-1.pm.1
- cleanups where rpmlint wasn't so happy
* Sat Jan  3 2009 Manfred.Tremmel@iiv.de
- remove NX in 11.1, it's no longer available
* Sat Oct 25 2008 Manfred.Tremmel@iiv.de
- update to 0.61.09
* Tue Sep 16 2008 Manfred.Tremmel@iiv.de
- recompile against new ffmpeg version
* Tue Mar  4 2008 Manfred.Tremmel@iiv.de
- update to 0.61.08
* Sat Feb 23 2008 Manfred.Tremmel@iiv.de
- update to svn (Revision 1808), because off security reasons
* Thu Dec 20 2007 Manfred Tremmel <Manfred.Tremmel@iiv.de>
- added patch to make it work with latest ffmpeg version
* Fri Oct 12 2007 Manfred.Tremmel@iiv.de
- update to 0.61.07
* Sat Jun 23 2007 Manfred.Tremmel@iiv.de
- update to 0.61.06
* Sun Dec 24 2006 Manfred.Tremmel@iiv.de
- update to svn (Revision 229), seems, a lot of bugs where fixed inbetween
* Thu Dec 21 2006 Manfred.Tremmel@iiv.de
- recompile with new libffmpeg version
* Wed Mar  1 2006 Manfred.Tremmel@iiv.de
- update to 0.61.05
* Mon Jan 23 2006 Manfred.Tremmel@iiv.de
- recompile with new libffmpeg version
* Sun Jan 15 2006 Manfred.Tremmel@iiv.de
- update to 0.61.04
* Thu Dec 15 2005 Manfred.Tremmel@iiv.de
- first packman build, based on the spec-file
  from Robert B. Quattlebaum Jr. <darco@bigfoot.com>
